class HTTPException(Exception):
    def __init__(self, status_code: int, message: str):
        super().__init__(message)
        self.status_code = status_code

    def get_status_code(self) -> int:
        return self.status_code

    def get_message(self) -> str:
        return self.__str__()



import json

from datetime import datetime

from abstractioutils.providers.aws.base import Base
from abstractioutils.exceptions.aws.sqs_exception import SQSException


class SQS(Base):
    def __init__(self):
        super().__init__('sqs')

    def send_message(self, queue_url: str, message_body: dict) -> str:
        try:
            message_ack = self._get_client().send_message(
                QueueUrl=queue_url,
                MessageBody=json.dumps(message_body)
            )

            return message_ack.get('MessageId')
        except Exception as exc:
            print(f"{datetime.now()} - Error while sending message to SQS - {exc}")
            raise SQSException(status_code=500, message=exc.__str__())



import json

from datetime import datetime

from abstractioutils.providers.aws.base import Base
from abstractioutils.exceptions.aws.sns_exception import SNSException


class SNS(Base):
    def __init__(self):
        super().__init__('sns')

    def publish_message(self, topic_arn: str, message: dict) -> str:
        try:
            message_ack = self._get_client().publish(
                TopicArn=topic_arn,
                Message=json.dumps(message)
            )

            return message_ack.get('MessageId')
        except Exception as exc:
            print(f"{datetime.now()} - Error while publishing message to SNS - {exc}")
            raise SNSException(status_code=500, message=exc.__str__())



import abc
import boto3


class Base(metaclass=abc.ABCMeta):
    def __init__(self, service: str):
        self.__client = boto3.client(service)

    def _get_client(self):
        return self.__client



from datetime import datetime

from abstractioutils.providers.aws.base import Base
from abstractioutils.exceptions.aws.ssm_exception import SSMException


class SSM(Base):
    def __init__(self):
        super().__init__('ssm')

    def get_parameter(self, name: str) -> str:
        try:
            parameter = self._get_client().get_parameter(
                Name=name
            )
        except Exception as exc:
            print(f"{datetime.now()} - Error while getting SSM param - {exc}")
            raise SSMException(status_code=500, message=exc.__str__())
        if 'Parameter' not in parameter:
            print(f"{datetime.now()} - Parameter {name} not found")
            raise SSMException(status_code=500, message='Parameter not found')
        return parameter['Parameter']['Value']
